import ssl


# Exported from OpenSSL 1.1.1a with ALL ciphers string. We use this lookup
# table to support older OpenSSL versions (looking at you, Homebrew, who uses
# their old OpenSSL for Python: https://github.com/Homebrew/homebrew-core/issues/8974)
_ciphersuite_lookup_table = {
    'TLS_AES_256_GCM_SHA384': {
        'id': 50336514,
        'name': 'TLS_AES_256_GCM_SHA384',
        'protocol': 'TLSv1.3',
        'description': 'TLS_AES_256_GCM_SHA384  TLSv1.3 Kx=any      Au=any  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'TLS_CHACHA20_POLY1305_SHA256': {
        'id': 50336515,
        'name': 'TLS_CHACHA20_POLY1305_SHA256',
        'protocol': 'TLSv1.3',
        'description': 'TLS_CHACHA20_POLY1305_SHA256 TLSv1.3 Kx=any      Au=any  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'TLS_AES_128_GCM_SHA256': {
        'id': 50336513,
        'name': 'TLS_AES_128_GCM_SHA256',
        'protocol': 'TLSv1.3',
        'description': 'TLS_AES_128_GCM_SHA256  TLSv1.3 Kx=any      Au=any  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-any',
        'auth': 'auth-any'},
    'ECDHE-ECDSA-AES256-GCM-SHA384': {
        'id': 50380844,
        'name': 'ECDHE-ECDSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-GCM-SHA384': {
        'id': 50380848,
        'name': 'ECDHE-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-GCM-SHA384': {
        'id': 50331811,
        'name': 'DHE-DSS-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES256-GCM-SHA384 TLSv1.2 Kx=DH       Au=DSS  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-AES256-GCM-SHA384': {
        'id': 50331807,
        'name': 'DHE-RSA-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-GCM-SHA384 TLSv1.2 Kx=DH       Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-CHACHA20-POLY1305': {
        'id': 50384041,
        'name': 'ECDHE-ECDSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CHACHA20-POLY1305 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CHACHA20-POLY1305': {
        'id': 50384040,
        'name': 'ECDHE-RSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CHACHA20-POLY1305 TLSv1.2 Kx=ECDH     Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CHACHA20-POLY1305': {
        'id': 50384042,
        'name': 'DHE-RSA-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CHACHA20-POLY1305 TLSv1.2 Kx=DH       Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-AES256-CCM8': {
        'id': 50380975,
        'name': 'ECDHE-ECDSA-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-CCM8 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ECDSA-AES256-CCM': {
        'id': 50380973,
        'name': 'ECDHE-ECDSA-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-CCM  TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'DHE-RSA-AES256-CCM8': {
        'id': 50380963,
        'name': 'DHE-RSA-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-CCM8     TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-CCM': {
        'id': 50380959,
        'name': 'DHE-RSA-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-CCM      TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-ARIA256-GCM-SHA384': {
        'id': 50380893,
        'name': 'ECDHE-ECDSA-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-ARIA256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ARIA256-GCM-SHA384': {
        'id': 50380897,
        'name': 'ECDHE-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ARIA256-GCM-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-ARIA256-GCM-SHA384': {
        'id': 50380887,
        'name': 'DHE-DSS-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-ARIA256-GCM-SHA384 TLSv1.2 Kx=DH       Au=DSS  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-ARIA256-GCM-SHA384': {
        'id': 50380883,
        'name': 'DHE-RSA-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-ARIA256-GCM-SHA384 TLSv1.2 Kx=DH       Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ADH-AES256-GCM-SHA384': {
        'id': 50331815,
        'name': 'ADH-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES256-GCM-SHA384   TLSv1.2 Kx=DH       Au=None Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-GCM-SHA256': {
        'id': 50380843,
        'name': 'ECDHE-ECDSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-GCM-SHA256': {
        'id': 50380847,
        'name': 'ECDHE-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-GCM-SHA256': {
        'id': 50331810,
        'name': 'DHE-DSS-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES128-GCM-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-AES128-GCM-SHA256': {
        'id': 50331806,
        'name': 'DHE-RSA-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-GCM-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-AES128-CCM8': {
        'id': 50380974,
        'name': 'ECDHE-ECDSA-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-CCM8 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ECDSA-AES128-CCM': {
        'id': 50380972,
        'name': 'ECDHE-ECDSA-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-CCM  TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'DHE-RSA-AES128-CCM8': {
        'id': 50380962,
        'name': 'DHE-RSA-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-CCM8     TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-CCM': {
        'id': 50380958,
        'name': 'DHE-RSA-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-CCM      TLSv1.2 Kx=DH       Au=RSA  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ECDHE-ECDSA-ARIA128-GCM-SHA256': {
        'id': 50380892,
        'name': 'ECDHE-ECDSA-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-ARIA128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-ARIA128-GCM-SHA256': {
        'id': 50380896,
        'name': 'ECDHE-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ARIA128-GCM-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-ARIA128-GCM-SHA256': {
        'id': 50380886,
        'name': 'DHE-DSS-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-ARIA128-GCM-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-ARIA128-GCM-SHA256': {
        'id': 50380882,
        'name': 'DHE-RSA-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-ARIA128-GCM-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'ADH-AES128-GCM-SHA256': {
        'id': 50331814,
        'name': 'ADH-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES128-GCM-SHA256   TLSv1.2 Kx=DH       Au=None Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES256-SHA384': {
        'id': 50380836,
        'name': 'ECDHE-ECDSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES256-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-SHA384': {
        'id': 50380840,
        'name': 'ECDHE-RSA-AES256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES256-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-SHA256': {
        'id': 50331755,
        'name': 'DHE-RSA-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES256-SHA256   TLSv1.2 Kx=DH       Au=RSA  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-SHA256': {
        'id': 50331754,
        'name': 'DHE-DSS-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES256-SHA256   TLSv1.2 Kx=DH       Au=DSS  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ECDHE-ECDSA-CAMELLIA256-SHA384': {
        'id': 50380915,
        'name': 'ECDHE-ECDSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CAMELLIA256-SHA384': {
        'id': 50380919,
        'name': 'ECDHE-RSA-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CAMELLIA256-SHA384 TLSv1.2 Kx=ECDH     Au=RSA  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CAMELLIA256-SHA256': {
        'id': 50331844,
        'name': 'DHE-RSA-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CAMELLIA256-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA256-SHA256': {
        'id': 50331843,
        'name': 'DHE-DSS-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-CAMELLIA256-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ADH-AES256-SHA256': {
        'id': 50331757,
        'name': 'ADH-AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES256-SHA256       TLSv1.2 Kx=DH       Au=None Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA256-SHA256': {
        'id': 50331845,
        'name': 'ADH-CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-CAMELLIA256-SHA256  TLSv1.2 Kx=DH       Au=None Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-SHA256': {
        'id': 50380835,
        'name': 'ECDHE-ECDSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-AES128-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-SHA256': {
        'id': 50380839,
        'name': 'ECDHE-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-AES128-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-SHA256': {
        'id': 50331751,
        'name': 'DHE-RSA-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-AES128-SHA256   TLSv1.2 Kx=DH       Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-SHA256': {
        'id': 50331712,
        'name': 'DHE-DSS-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-AES128-SHA256   TLSv1.2 Kx=DH       Au=DSS  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ECDHE-ECDSA-CAMELLIA128-SHA256': {
        'id': 50380914,
        'name': 'ECDHE-ECDSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-ECDSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH     Au=ECDSA Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-CAMELLIA128-SHA256': {
        'id': 50380918,
        'name': 'ECDHE-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=ECDH     Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-CAMELLIA128-SHA256': {
        'id': 50331838,
        'name': 'DHE-RSA-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-RSA-CAMELLIA128-SHA256 TLSv1.2 Kx=DH       Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA128-SHA256': {
        'id': 50331837,
        'name': 'DHE-DSS-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-DSS-CAMELLIA128-SHA256 TLSv1.2 Kx=DH       Au=DSS  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'ADH-AES128-SHA256': {
        'id': 50331756,
        'name': 'ADH-AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-AES128-SHA256       TLSv1.2 Kx=DH       Au=None Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA128-SHA256': {
        'id': 50331839,
        'name': 'ADH-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ADH-CAMELLIA128-SHA256  TLSv1.2 Kx=DH       Au=None Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES256-SHA': {
        'id': 50380810,
        'name': 'ECDHE-ECDSA-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-ECDSA-AES256-SHA  TLSv1 Kx=ECDH     Au=ECDSA Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES256-SHA': {
        'id': 50380820,
        'name': 'ECDHE-RSA-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-RSA-AES256-SHA    TLSv1 Kx=ECDH     Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES256-SHA': {
        'id': 50331705,
        'name': 'DHE-RSA-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-AES256-SHA      SSLv3 Kx=DH       Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES256-SHA': {
        'id': 50331704,
        'name': 'DHE-DSS-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-AES256-SHA      SSLv3 Kx=DH       Au=DSS  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-CAMELLIA256-SHA': {
        'id': 50331784,
        'name': 'DHE-RSA-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-CAMELLIA256-SHA SSLv3 Kx=DH       Au=RSA  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA256-SHA': {
        'id': 50331783,
        'name': 'DHE-DSS-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-CAMELLIA256-SHA SSLv3 Kx=DH       Au=DSS  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'AECDH-AES256-SHA': {
        'id': 50380825,
        'name': 'AECDH-AES256-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-AES256-SHA        TLSv1 Kx=ECDH     Au=None Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'},
    'ADH-AES256-SHA': {
        'id': 50331706,
        'name': 'ADH-AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-AES256-SHA          SSLv3 Kx=DH       Au=None Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA256-SHA': {
        'id': 50331785,
        'name': 'ADH-CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-CAMELLIA256-SHA     SSLv3 Kx=DH       Au=None Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ECDHE-ECDSA-AES128-SHA': {
        'id': 50380809,
        'name': 'ECDHE-ECDSA-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-ECDSA-AES128-SHA  TLSv1 Kx=ECDH     Au=ECDSA Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-ecdsa'},
    'ECDHE-RSA-AES128-SHA': {
        'id': 50380819,
        'name': 'ECDHE-RSA-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-RSA-AES128-SHA    TLSv1 Kx=ECDH     Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-rsa'},
    'DHE-RSA-AES128-SHA': {
        'id': 50331699,
        'name': 'DHE-RSA-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-AES128-SHA      SSLv3 Kx=DH       Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-AES128-SHA': {
        'id': 50331698,
        'name': 'DHE-DSS-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-AES128-SHA      SSLv3 Kx=DH       Au=DSS  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-SEED-SHA': {
        'id': 50331802,
        'name': 'DHE-RSA-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-SEED-SHA        SSLv3 Kx=DH       Au=RSA  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-SEED-SHA': {
        'id': 50331801,
        'name': 'DHE-DSS-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-SEED-SHA        SSLv3 Kx=DH       Au=DSS  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'DHE-RSA-CAMELLIA128-SHA': {
        'id': 50331717,
        'name': 'DHE-RSA-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-RSA-CAMELLIA128-SHA SSLv3 Kx=DH       Au=RSA  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-rsa'},
    'DHE-DSS-CAMELLIA128-SHA': {
        'id': 50331716,
        'name': 'DHE-DSS-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-DSS-CAMELLIA128-SHA SSLv3 Kx=DH       Au=DSS  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-dss'},
    'AECDH-AES128-SHA': {
        'id': 50380824,
        'name': 'AECDH-AES128-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-AES128-SHA        TLSv1 Kx=ECDH     Au=None Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'},
    'ADH-AES128-SHA': {
        'id': 50331700,
        'name': 'ADH-AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-AES128-SHA          SSLv3 Kx=DH       Au=None Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-SEED-SHA': {
        'id': 50331803,
        'name': 'ADH-SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-SEED-SHA            SSLv3 Kx=DH       Au=None Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'ADH-CAMELLIA128-SHA': {
        'id': 50331718,
        'name': 'ADH-CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'ADH-CAMELLIA128-SHA     SSLv3 Kx=DH       Au=None Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe',
        'auth': 'auth-null'},
    'RSA-PSK-AES256-GCM-SHA384': {
        'id': 50331821,
        'name': 'RSA-PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-AES256-GCM-SHA384 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-GCM-SHA384': {
        'id': 50331819,
        'name': 'DHE-PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-GCM-SHA384 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CHACHA20-POLY1305': {
        'id': 50384046,
        'name': 'RSA-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CHACHA20-POLY1305': {
        'id': 50384045,
        'name': 'DHE-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CHACHA20-POLY1305': {
        'id': 50384044,
        'name': 'ECDHE-PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'ECDHE-PSK-CHACHA20-POLY1305 TLSv1.2 Kx=ECDHEPSK Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES256-CCM8': {
        'id': 50380971,
        'name': 'DHE-PSK-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-CCM8     TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES256-CCM': {
        'id': 50380967,
        'name': 'DHE-PSK-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES256-CCM      TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-ARIA256-GCM-SHA384': {
        'id': 50380911,
        'name': 'RSA-PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-ARIA256-GCM-SHA384 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-ARIA256-GCM-SHA384': {
        'id': 50380909,
        'name': 'DHE-PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-ARIA256-GCM-SHA384 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES256-GCM-SHA384': {
        'id': 50331805,
        'name': 'AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'AES256-GCM-SHA384       TLSv1.2 Kx=RSA      Au=RSA  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES256-CCM8': {
        'id': 50380961,
        'name': 'AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'AES256-CCM8             TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES256-CCM': {
        'id': 50380957,
        'name': 'AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'AES256-CCM              TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ARIA256-GCM-SHA384': {
        'id': 50380881,
        'name': 'ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'ARIA256-GCM-SHA384      TLSv1.2 Kx=RSA      Au=RSA  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES256-GCM-SHA384': {
        'id': 50331817,
        'name': 'PSK-AES256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-GCM-SHA384   TLSv1.2 Kx=PSK      Au=PSK  Enc=AESGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CHACHA20-POLY1305': {
        'id': 50384043,
        'name': 'PSK-CHACHA20-POLY1305',
        'protocol': 'TLSv1.2',
        'description': 'PSK-CHACHA20-POLY1305   TLSv1.2 Kx=PSK      Au=PSK  Enc=CHACHA20/POLY1305(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'chacha20-poly1305',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CCM8': {
        'id': 50380969,
        'name': 'PSK-AES256-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-CCM8         TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM8(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CCM': {
        'id': 50380965,
        'name': 'PSK-AES256-CCM',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES256-CCM          TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aes-256-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-ARIA256-GCM-SHA384': {
        'id': 50380907,
        'name': 'PSK-ARIA256-GCM-SHA384',
        'protocol': 'TLSv1.2',
        'description': 'PSK-ARIA256-GCM-SHA384  TLSv1.2 Kx=PSK      Au=PSK  Enc=ARIAGCM(256) Mac=AEAD',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': True,
        'symmetric': 'aria-256-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES128-GCM-SHA256': {
        'id': 50331820,
        'name': 'RSA-PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-AES128-GCM-SHA256 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-GCM-SHA256': {
        'id': 50331818,
        'name': 'DHE-PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-GCM-SHA256 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES128-CCM8': {
        'id': 50380970,
        'name': 'DHE-PSK-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-CCM8     TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'DHE-PSK-AES128-CCM': {
        'id': 50380966,
        'name': 'DHE-PSK-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-AES128-CCM      TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-ARIA128-GCM-SHA256': {
        'id': 50380910,
        'name': 'RSA-PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'RSA-PSK-ARIA128-GCM-SHA256 TLSv1.2 Kx=RSAPSK   Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-ARIA128-GCM-SHA256': {
        'id': 50380908,
        'name': 'DHE-PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'DHE-PSK-ARIA128-GCM-SHA256 TLSv1.2 Kx=DHEPSK   Au=PSK  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES128-GCM-SHA256': {
        'id': 50331804,
        'name': 'AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES128-GCM-SHA256       TLSv1.2 Kx=RSA      Au=RSA  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-CCM8': {
        'id': 50380960,
        'name': 'AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'AES128-CCM8             TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-CCM': {
        'id': 50380956,
        'name': 'AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'AES128-CCM              TLSv1.2 Kx=RSA      Au=RSA  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ARIA128-GCM-SHA256': {
        'id': 50380880,
        'name': 'ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'ARIA128-GCM-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES128-GCM-SHA256': {
        'id': 50331816,
        'name': 'PSK-AES128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-GCM-SHA256   TLSv1.2 Kx=PSK      Au=PSK  Enc=AESGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CCM8': {
        'id': 50380968,
        'name': 'PSK-AES128-CCM8',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-CCM8         TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM8(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CCM': {
        'id': 50380964,
        'name': 'PSK-AES128-CCM',
        'protocol': 'TLSv1.2',
        'description': 'PSK-AES128-CCM          TLSv1.2 Kx=PSK      Au=PSK  Enc=AESCCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aes-128-ccm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-ARIA128-GCM-SHA256': {
        'id': 50380906,
        'name': 'PSK-ARIA128-GCM-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'PSK-ARIA128-GCM-SHA256  TLSv1.2 Kx=PSK      Au=PSK  Enc=ARIAGCM(128) Mac=AEAD',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': True,
        'symmetric': 'aria-128-gcm',
        'digest': None,
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'AES256-SHA256': {
        'id': 50331709,
        'name': 'AES256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES256-SHA256           TLSv1.2 Kx=RSA      Au=RSA  Enc=AES(256)  Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA256-SHA256': {
        'id': 50331840,
        'name': 'CAMELLIA256-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'CAMELLIA256-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=Camellia(256) Mac=SHA256',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'AES128-SHA256': {
        'id': 50331708,
        'name': 'AES128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'AES128-SHA256           TLSv1.2 Kx=RSA      Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA128-SHA256': {
        'id': 50331834,
        'name': 'CAMELLIA128-SHA256',
        'protocol': 'TLSv1.2',
        'description': 'CAMELLIA128-SHA256      TLSv1.2 Kx=RSA      Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'ECDHE-PSK-AES256-CBC-SHA384': {
        'id': 50380856,
        'name': 'ECDHE-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES256-CBC-SHA384 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES256-CBC-SHA': {
        'id': 50380854,
        'name': 'ECDHE-PSK-AES256-CBC-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES256-CBC-SHA TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'SRP-DSS-AES-256-CBC-SHA': {
        'id': 50380834,
        'name': 'SRP-DSS-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-DSS-AES-256-CBC-SHA SSLv3 Kx=SRP      Au=DSS  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-dss'},
    'SRP-RSA-AES-256-CBC-SHA': {
        'id': 50380833,
        'name': 'SRP-RSA-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-RSA-AES-256-CBC-SHA SSLv3 Kx=SRP      Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-rsa'},
    'SRP-AES-256-CBC-SHA': {
        'id': 50380832,
        'name': 'SRP-AES-256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-AES-256-CBC-SHA     SSLv3 Kx=SRP      Au=SRP  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-srp'},
    'RSA-PSK-AES256-CBC-SHA384': {
        'id': 50331831,
        'name': 'RSA-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-AES256-CBC-SHA384 TLSv1 Kx=RSAPSK   Au=RSA  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-CBC-SHA384': {
        'id': 50331827,
        'name': 'DHE-PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-AES256-CBC-SHA384 TLSv1 Kx=DHEPSK   Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES256-CBC-SHA': {
        'id': 50331797,
        'name': 'RSA-PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'RSA-PSK-AES256-CBC-SHA  SSLv3 Kx=RSAPSK   Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES256-CBC-SHA': {
        'id': 50331793,
        'name': 'DHE-PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-PSK-AES256-CBC-SHA  SSLv3 Kx=DHEPSK   Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CAMELLIA256-SHA384': {
        'id': 50380955,
        'name': 'ECDHE-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-CAMELLIA256-SHA384 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CAMELLIA256-SHA384': {
        'id': 50380953,
        'name': 'RSA-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-CAMELLIA256-SHA384 TLSv1 Kx=RSAPSK   Au=RSA  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CAMELLIA256-SHA384': {
        'id': 50380951,
        'name': 'DHE-PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-CAMELLIA256-SHA384 TLSv1 Kx=DHEPSK   Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES256-SHA': {
        'id': 50331701,
        'name': 'AES256-SHA',
        'protocol': 'SSLv3',
        'description': 'AES256-SHA              SSLv3 Kx=RSA      Au=RSA  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA256-SHA': {
        'id': 50331780,
        'name': 'CAMELLIA256-SHA',
        'protocol': 'SSLv3',
        'description': 'CAMELLIA256-SHA         SSLv3 Kx=RSA      Au=RSA  Enc=Camellia(256) Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES256-CBC-SHA384': {
        'id': 50331823,
        'name': 'PSK-AES256-CBC-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'PSK-AES256-CBC-SHA384   TLSv1 Kx=PSK      Au=PSK  Enc=AES(256)  Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES256-CBC-SHA': {
        'id': 50331789,
        'name': 'PSK-AES256-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'PSK-AES256-CBC-SHA      SSLv3 Kx=PSK      Au=PSK  Enc=AES(256)  Mac=SHA1',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'aes-256-cbc',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CAMELLIA256-SHA384': {
        'id': 50380949,
        'name': 'PSK-CAMELLIA256-SHA384',
        'protocol': 'TLSv1.0',
        'description': 'PSK-CAMELLIA256-SHA384  TLSv1 Kx=PSK      Au=PSK  Enc=Camellia(256) Mac=SHA384',
        'strength_bits': 256,
        'alg_bits': 256,
        'aead': False,
        'symmetric': 'camellia-256-cbc',
        'digest': 'sha384',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES128-CBC-SHA256': {
        'id': 50380855,
        'name': 'ECDHE-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES128-CBC-SHA256 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-AES128-CBC-SHA': {
        'id': 50380853,
        'name': 'ECDHE-PSK-AES128-CBC-SHA',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-AES128-CBC-SHA TLSv1 Kx=ECDHEPSK Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'SRP-DSS-AES-128-CBC-SHA': {
        'id': 50380831,
        'name': 'SRP-DSS-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-DSS-AES-128-CBC-SHA SSLv3 Kx=SRP      Au=DSS  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-dss'},
    'SRP-RSA-AES-128-CBC-SHA': {
        'id': 50380830,
        'name': 'SRP-RSA-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-RSA-AES-128-CBC-SHA SSLv3 Kx=SRP      Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-rsa'},
    'SRP-AES-128-CBC-SHA': {
        'id': 50380829,
        'name': 'SRP-AES-128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'SRP-AES-128-CBC-SHA     SSLv3 Kx=SRP      Au=SRP  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-srp',
        'auth': 'auth-srp'},
    'RSA-PSK-AES128-CBC-SHA256': {
        'id': 50331830,
        'name': 'RSA-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-AES128-CBC-SHA256 TLSv1 Kx=RSAPSK   Au=RSA  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-CBC-SHA256': {
        'id': 50331826,
        'name': 'DHE-PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-AES128-CBC-SHA256 TLSv1 Kx=DHEPSK   Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-AES128-CBC-SHA': {
        'id': 50331796,
        'name': 'RSA-PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'RSA-PSK-AES128-CBC-SHA  SSLv3 Kx=RSAPSK   Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-AES128-CBC-SHA': {
        'id': 50331792,
        'name': 'DHE-PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'DHE-PSK-AES128-CBC-SHA  SSLv3 Kx=DHEPSK   Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'ECDHE-PSK-CAMELLIA128-SHA256': {
        'id': 50380954,
        'name': 'ECDHE-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'ECDHE-PSK-CAMELLIA128-SHA256 TLSv1 Kx=ECDHEPSK Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-ecdhe-psk',
        'auth': 'auth-psk'},
    'RSA-PSK-CAMELLIA128-SHA256': {
        'id': 50380952,
        'name': 'RSA-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'RSA-PSK-CAMELLIA128-SHA256 TLSv1 Kx=RSAPSK   Au=RSA  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-rsa-psk',
        'auth': 'auth-rsa'},
    'DHE-PSK-CAMELLIA128-SHA256': {
        'id': 50380950,
        'name': 'DHE-PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'DHE-PSK-CAMELLIA128-SHA256 TLSv1 Kx=DHEPSK   Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-dhe-psk',
        'auth': 'auth-psk'},
    'AES128-SHA': {
        'id': 50331695,
        'name': 'AES128-SHA',
        'protocol': 'SSLv3',
        'description': 'AES128-SHA              SSLv3 Kx=RSA      Au=RSA  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'SEED-SHA': {
        'id': 50331798,
        'name': 'SEED-SHA',
        'protocol': 'SSLv3',
        'description': 'SEED-SHA                SSLv3 Kx=RSA      Au=RSA  Enc=SEED(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'seed-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'CAMELLIA128-SHA': {
        'id': 50331713,
        'name': 'CAMELLIA128-SHA',
        'protocol': 'SSLv3',
        'description': 'CAMELLIA128-SHA         SSLv3 Kx=RSA      Au=RSA  Enc=Camellia(128) Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-rsa',
        'auth': 'auth-rsa'},
    'PSK-AES128-CBC-SHA256': {
        'id': 50331822,
        'name': 'PSK-AES128-CBC-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'PSK-AES128-CBC-SHA256   TLSv1 Kx=PSK      Au=PSK  Enc=AES(128)  Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-AES128-CBC-SHA': {
        'id': 50331788,
        'name': 'PSK-AES128-CBC-SHA',
        'protocol': 'SSLv3',
        'description': 'PSK-AES128-CBC-SHA      SSLv3 Kx=PSK      Au=PSK  Enc=AES(128)  Mac=SHA1',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'aes-128-cbc',
        'digest': 'sha1',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'PSK-CAMELLIA128-SHA256': {
        'id': 50380948,
        'name': 'PSK-CAMELLIA128-SHA256',
        'protocol': 'TLSv1.0',
        'description': 'PSK-CAMELLIA128-SHA256  TLSv1 Kx=PSK      Au=PSK  Enc=Camellia(128) Mac=SHA256',
        'strength_bits': 128,
        'alg_bits': 128,
        'aead': False,
        'symmetric': 'camellia-128-cbc',
        'digest': 'sha256',
        'kea': 'kx-psk',
        'auth': 'auth-psk'},
    'AECDH-NULL-SHA': {
        'id': 50380821,
        'name': 'AECDH-NULL-SHA',
        'protocol': 'TLSv1.0',
        'description': 'AECDH-NULL-SHA          TLSv1 Kx=ECDH     Au=None Enc=None      Mac=SHA1',
        'strength_bits': 0,
        'alg_bits': 0,
        'aead': False,
        'symmetric': None,
        'digest': 'sha1',
        'kea': 'kx-ecdhe',
        'auth': 'auth-null'}}


def lookup_ciphersuite(cipersuite_name):
    try:
        return _ciphersuite_lookup_table[cipersuite_name]
    except KeyError:
        # TLS connections in privacyscanner use the default context, so our
        # cipher should be definitely inside.
        context = ssl.create_default_context()
        ciphers_lookup = {cipher['name']: cipher for cipher in context.get_ciphers()}
        cipher_info = ciphers_lookup[cipersuite_name]
        if 'symmetric' not in cipher_info:
            raise RuntimeError('OpenSSL 1.1 is required. Even Debian 9 has it.')
        return cipher_info
